@@ -15,7 +15,7 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with obob_subjectdb. If not, see <http://www.gnu.org/licenses/>.
-
+import datetime
 import sys
 import os
 import socket
@@ -68,15 +68,19 @@ if __name__ == '__main__':
 
     job_object = job_item.make_object()
 
+    job_started = datetime.datetime.now()
+
     print('Running on: %s' % (socket.gethostname(), ))
     print('Now running %s' % (job_item, ))
     print('Parameters: %s' % (job_item.args, ))
     print('Keyword Parameters: %s' % (job_item.kwargs, ))
     print('\nThe job has the ID: %d.%d' % (job_info['ClusterId'], job_info['ProcId']))
 
-    print('Starting Job\n##########')
+    print(f'Starting Job at {job_started}\n##########')
     job_object.run_private()
-    print('##########\nJob stopped')
+    job_stopped = datetime.datetime.now()
+    print(f'##########\nJob stopped at {job_stopped}')
+    print(f'Execution took {job_stopped - job_started}')
     mem_used_raw = get_classad('MemoryUsage', job_info['ClusterId'], job_info['ProcId'])
     if mem_used_raw.startswith('undefined'):
         mem_used = 0
