@@ -145,16 +145,20 @@ class AutomaticFilenameJob(Job):
 
     In order for this to work, you need to:
 
-    1. Include a keyword argument called ``subject_id`` when instantiating this Job.
-    2. Set :attr:`base_data_folder` and :attr:`job_data_folder` as a class attribute.
-    3. If you use :meth:`shall_run`, you need to do the super call.
+    1. Set :attr:`base_data_folder` and :attr:`job_data_folder` as a class attribute.
+    2. If you use :meth:`shall_run`, you need to do the super call.
+
+    This class then automatically creates the filename for each job using all
+    the keyword arguments supplied.
+
+    Please take a look at :doc:`autofilename` for detailed examples.
 
     Attributes
     ----------
-    base_data_folder : str or Path
+    base_data_folder : str or pathlib.Path
         The base folder for the data. Is normally set once for all jobs of a project.
 
-    job_data_folder : str or Path
+    job_data_folder : str or pathlib.Path
         The folder where the data for this job should be saved.
 
     exclude_kwargs_from_filename : list
@@ -168,12 +172,22 @@ class AutomaticFilenameJob(Job):
 
     run_only_when_not_existing : bool
         If true, this job will only run if the file does not already exist.
+
+    create_folder : bool
+        If true, calling folders are created automatically
+
+    data_file_suffix : str, optional
+        The extension of the file. Defaults to `.dat`
+
+
     """
     base_data_folder = ''
     job_data_folder = ''
     exclude_kwargs_from_filename = []
     include_hash_in_fname = False
     run_only_when_not_existing = True
+    create_folders = True
+    data_file_suffix = '.dat'
 
     def __init__(self, *args, **kwargs):
         if 'subject_id' not in kwargs:
@@ -195,19 +209,30 @@ class AutomaticFilenameJob(Job):
         if not cls.job_data_folder:
             raise ValueError('job_data_folder must be set')
 
-        return Path(cls.base_data_folder, cls.job_data_folder)
+        folder = Path(cls.base_data_folder, cls.job_data_folder)
+
+        if cls.create_folders:
+            folder.mkdir(exist_ok=True, parents=True)
+
+        return folder
 
     @property
     def output_folder(self):
         """
-        The output folder for this subject.
+        pathlib.Path: The output folder for this subject.
         """
-        return Path(self.get_full_data_folder(), self.subject_id)
+
+        folder = Path(self.get_full_data_folder(), self.subject_id)
+
+        if self.create_folders:
+            folder.mkdir(exist_ok=True, parents=True)
+
+        return folder
 
     @property
     def output_filename(self):
         """
-        The filename for this subject.
+        str: The filename for this subject.
         """
         f_name_list = [self.subject_id]
 
@@ -220,14 +245,14 @@ class AutomaticFilenameJob(Job):
         if self.include_hash_in_fname:
             f_name_list.append(self.make_hash_from_args())
 
-        f_name = '__'.join(f_name_list) + '.dat'
+        f_name = '__'.join(f_name_list) + self.data_file_suffix
 
         return f_name
 
     @property
     def full_output_path(self):
         """
-        The full path to the output file.
+        pathlib.Path: The full path to the output file.
         """
         return Path(self.output_folder, self.output_filename)
 
